@@ -63,7 +63,7 @@ typedef struct{
 
 GType                gpm_brightness_applet_get_type  (void);
 
-#define GSD_DBUS_SERVICE	"org.gnome.SettingsDaemon"
+#define GSD_DBUS_SERVICE	"org.gnome.SettingsDaemon.Power"
 #define GSD_DBUS_PATH_POWER	"/org/gnome/SettingsDaemon/Power"
 
 G_DEFINE_TYPE (GpmBrightnessApplet, gpm_brightness_applet, PANEL_TYPE_APPLET)
